@@ -32,7 +32,7 @@ def get_markdown_images_format(text):
     images_list=[]
     for it in text.split("\n"):
         if len(it) >0:
-            it=it.strip()
+            it=it.strip().replace(" .",'.').replace(" !",'!').replace(" ;",';').replace(" ?",'?')
             image_arr = re.findall(r'(?:!\[(.*?)\]\((.*?)\))', it)
             if len(image_arr) > 0:
                 images_list.append(image_arr)
